﻿using Hotline.KnowledgeBase;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos;
using Hotline.Share.Enums.KnowledgeBase;
using Microsoft.AspNetCore.Mvc;
using Hotline.Share.Dtos.Quality;
using Org.BouncyCastle.Utilities;
using Polly.Caching;
using SqlSugar;
using Hotline.Settings;
using XF.Utility.EnumExtensions;

namespace Hotline.Api.Controllers.Bi
{
	public class BiKnowledgeController : BaseController
	{
		private readonly IKnowledgeRepository _knowledgeRepository;
		public BiKnowledgeController(IKnowledgeRepository knowledgeRepository) 
		{
			_knowledgeRepository = knowledgeRepository;
		}

		[HttpGet("data_list")]
		public async Task<PagedDto<KnowledgeBiDataListVo>> DataList([FromQuery] QualityBiDataListDto dto)
		{
			var total = 0;
			var query = _knowledgeRepository.Queryable(false,true,false)
				.LeftJoin<SystemOrganize>((x,o)=>x.SourceOrganizeId == o.Id)
				.WhereIF(dto.CreationTimeStart.HasValue, (x,o) => x.CreationTime >= dto.CreationTimeStart)
				.WhereIF(dto.CreationTimeEnd.HasValue, (x,o)=> x.CreationTime <= dto.CreationTimeEnd)
				.GroupBy((x,o) =>  new { x.SourceOrganizeId, o.Name, o.OrgType })
				.Select((x,o) => new KnowledgeBiDataListVo
				{
					OrgName = o.Name,
					OrgId = x.SourceOrganizeId,
					OrgType = o.OrgType,
					AddNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.OnShelf, 1, 0)),
					DeleteNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.IsDeleted, 1, 0)),
					SendBackNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.Revert, 1, 0)),
					PassNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.OnShelf, 1, 0))
				}).MergeTable();
			switch (dto.SortField)
			{
				case 0:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.AddNum) : query.OrderByDescending(x => x.AddNum);
					break;
				case 1:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.DeleteNum) : query.OrderByDescending(x => x.DeleteNum);
					break;
				case 2:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.SendBackNum) : query.OrderByDescending(x => x.SendBackNum);
					break;
				case 3:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.PassNum) : query.OrderByDescending(x => x.PassNum);
					break;
			}
            var  items = query.ToPageList(dto.PageIndex, dto.PageSize,ref total);
			return new PagedDto<KnowledgeBiDataListVo>(total, items);
		}
	}
}
